# Canvas Tools
A set of tools for working with Canvas.

## Currently available tools

`canvas_group_csv`: Export your canvas student groups into a CSV file. Ready for Zoom breakout room CSV import.

## Install

`pip3 install canvas_tools`

## Usage

Run `canvas_group_csv -h` will give you the help documentation for that command.